@@ -55,19 +55,19 @@ def get_historical_portfolio(interval=None, span='week', bounds='regular',info=N
 
     if interval not in interval_check:
         if interval is None and (bounds != 'regular' and span != 'all'):
-            print ('ERROR: Interval must be None for "all" span "regular" bounds')
+            print ('ERROR: Interval must be None for "all" span "regular" bounds', file=helper.get_output())
             return ([None])
         print(
-            'ERROR: Interval must be "5minute","10minute","hour","day",or "week"')
+            'ERROR: Interval must be "5minute","10minute","hour","day",or "week"', file=helper.get_output())
         return([None])
     if span not in span_check:
-        print('ERROR: Span must be "day","week","month","3month","year",or "5year"')
+        print('ERROR: Span must be "day","week","month","3month","year",or "5year"', file=helper.get_output())
         return([None])
     if bounds not in bounds_check:
         print('ERROR: Bounds must be "extended","regular",or "trading"')
         return([None])
     if (bounds == 'extended' or bounds == 'trading') and span != 'day':
-        print('ERROR: extended and trading bounds can only be used with a span of "day"')
+        print('ERROR: extended and trading bounds can only be used with a span of "day"', file=helper.get_output())
         return([None])
 
     account = profiles.load_account_profile('account_number')
@@ -282,7 +282,7 @@ def get_margin_calls(symbol=None):
         try:
             symbol = symbol.upper().strip()
         except AttributeError as message:
-            print(message)
+            print(message, file=helper.get_output())
             return None
         payload = {'equity_instrument_id', helper.id_for_stock(symbol)}
         data = helper.request_get(url, 'results', payload)
@@ -479,7 +479,7 @@ def download_document(url, name=None, dirpath=None):
     """
     data = helper.request_document(url)
 
-    print('Writing PDF...')
+    print('Writing PDF...', file=helper.get_output())
     if not name:
         name = url[36:].split('/', 1)[0]
 
@@ -530,7 +530,7 @@ def download_all_documents(doctype=None, dirpath=None):
                 open(filename, 'wb').write(data.content)
                 downloaded_files = True
                 counter += 1
-                print('Writing PDF {}...'.format(counter))
+                print('Writing PDF {}...'.format(counter), file=helper.get_output())
         else:
             if item['type'] == doctype:
                 data = helper.request_document(item['download_url'])
@@ -542,24 +542,24 @@ def download_all_documents(doctype=None, dirpath=None):
                     open(filename, 'wb').write(data.content)
                     downloaded_files = True
                     counter += 1
-                    print('Writing PDF {}...'.format(counter))
+                    print('Writing PDF {}...'.format(counter), file=helper.get_output())
 
     if downloaded_files == False:
-        print('WARNING: Could not find files of that doctype to download')
+        print('WARNING: Could not find files of that doctype to download', file=helper.get_output())
     else:
         if counter == 1:
             print('Done - wrote {} file to {}'.format(counter,
-                                                      os.path.abspath(directory)))
+                                                      os.path.abspath(directory)), file=helper.get_output())
         else:
             print('Done - wrote {} files to {}'.format(counter,
-                                                       os.path.abspath(directory)))
+                                                       os.path.abspath(directory)), file=helper.get_output())
 
     return(documents)
 
 
 @helper.login_required
 def get_all_watchlists(info=None):
-    """Returns a list of all watchlists that have been created. Everone has a 'default' watchlist.
+    """Returns a list of all watchlists that have been created. Everyone has a 'My First List' watchlist.
 
     :param info: Will filter the results to get a specific value.
     :type info: Optional[str]
@@ -572,7 +572,7 @@ def get_all_watchlists(info=None):
 
 
 @helper.login_required
-def get_watchlist_by_name(name='Default', info=None):
+def get_watchlist_by_name(name="My First List", info=None):
     """Returns a list of information related to the stocks in a single watchlist.
 
     :param name: The name of the watchlist to get data from.
@@ -596,7 +596,7 @@ def get_watchlist_by_name(name='Default', info=None):
 
 
 @helper.login_required
-def post_symbols_to_watchlist(inputSymbols, name='Default'):
+def post_symbols_to_watchlist(inputSymbols, name="My First List"):
     """Posts multiple stock tickers to a watchlist.
 
     :param inputSymbols: May be a single stock ticker or a list of stock tickers.
@@ -607,17 +607,31 @@ def post_symbols_to_watchlist(inputSymbols, name='Default'):
 
     """
     symbols = helper.inputs_to_set(inputSymbols)
-    payload = {
-        'symbols': ','.join(symbols)
-    }
-    url = urls.watchlists(name, True)
-    data = helper.request_post(url, payload)
+    ids = stocks.get_instruments_by_symbols(symbols, info='id')
+    data = []
+    #Get id of requested watchlist
+    all_watchlists = get_all_watchlists()
+    watchlist_id = ''
+    for wl in all_watchlists['results']:
+        if wl['display_name'] == name:
+            watchlist_id = wl['id']
+
+    for id in ids:
+        payload = {
+            watchlist_id: [{
+                "object_type" : "instrument",
+                "object_id" : id,
+                "operation" : "create"
+            }]
+        }
+        url = urls.watchlists(name, True)
+        data.append(helper.request_post(url, payload, json=True))
 
     return(data)
 
 
 @helper.login_required
-def delete_symbols_from_watchlist(inputSymbols, name='Default'):
+def delete_symbols_from_watchlist(inputSymbols, name="My First List"):
     """Deletes multiple stock tickers from a watchlist.
 
     :param inputSymbols: May be a single stock ticker or a list of stock tickers.
@@ -631,9 +645,23 @@ def delete_symbols_from_watchlist(inputSymbols, name='Default'):
     ids = stocks.get_instruments_by_symbols(symbols, info='id')
     data = []
 
+    #Get id of requested watchlist
+    all_watchlists = get_all_watchlists()
+    watchlist_id = ''
+    for wl in all_watchlists['results']:
+        if wl['display_name'] == name:
+            watchlist_id = wl['id']
+
     for id in ids:
-        url = urls.watchlist_delete(name, id)
-        data.append(helper.request_delete(url))
+        payload = {
+            watchlist_id: [{
+                "object_type" : "instrument",
+                "object_id" : id,
+                "operation" : "delete"
+            }]
+        }
+        url = urls.watchlists(name, True)
+        data.append(helper.request_post(url, payload, json=True))
 
     return(data)
 
