@@ -10,7 +10,7 @@ Functions
 from functools import wraps
 
 import requests
-from robin_stocks.globals import LOGGED_IN, SESSION
+from robin_stocks.globals import LOGGED_IN, SESSION, OUTPUT
 
 
 def set_login_state(logged_in):
@@ -18,6 +18,15 @@ def set_login_state(logged_in):
     global LOGGED_IN
     LOGGED_IN = logged_in
 
+def set_output(output):
+    """Sets the global output stream"""
+    global OUTPUT
+    OUTPUT = output
+    
+def get_output():
+    """Gets the current global output stream"""
+    global OUTPUT
+    return OUTPUT
 
 def login_required(func):
     """A decorator for indicating which methods require the user to be logged
@@ -55,7 +64,7 @@ def id_for_stock(symbol):
     try:
         symbol = symbol.upper().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=get_output())
         return(None)
 
     url = 'https://api.robinhood.com/instruments/'
@@ -76,7 +85,7 @@ def id_for_chain(symbol):
     try:
         symbol = symbol.upper().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=get_output())
         return(None)
 
     url = 'https://api.robinhood.com/instruments/'
@@ -101,7 +110,7 @@ def id_for_group(symbol):
     try:
         symbol = symbol.upper().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=get_output())
         return(None)
 
     url = 'https://api.robinhood.com/options/chains/{0}/'.format(
@@ -123,12 +132,12 @@ def id_for_option(symbol, expirationDate, strike, optionType):
     :type optionType: str
     :returns:  A string that represents the stocks option id.
 
-    """
+    """ 
     symbol = symbol.upper()
-
+    chain_id = id_for_chain(symbol)
     payload = {
-        'chain_symbol': symbol,
-        'expiration_date': expirationDate,
+        'chain_id': chain_id,
+        'expiration_dates': expirationDate,
         'strike_price': strike,
         'type': optionType,
         'state': 'active'
@@ -138,7 +147,7 @@ def id_for_option(symbol, expirationDate, strike, optionType):
 
     listOfOptions = [item for item in data if item["expiration_date"] == expirationDate]
     if (len(listOfOptions) == 0):
-        print('Getting the option ID failed. Perhaps the expiration date is wrong format, or the strike price is wrong.')
+        print('Getting the option ID failed. Perhaps the expiration date is wrong format, or the strike price is wrong.', file=get_output())
         return(None)
 
     return(listOfOptions[0]['id'])
@@ -192,7 +201,7 @@ def filter(data, info):
         elif info in compareDict and type(data) == dict:
             return(data[info])
         else:
-            print(error_argument_not_key_in_dictionary(info))
+            print(error_argument_not_key_in_dictionary(info), file=get_output())
             return(noneType)
     else:
         return(data)
@@ -235,12 +244,12 @@ def request_document(url, payload=None):
     :type url: str
     :returns: Returns the session.get() data as opppose to session.get().json() data.
 
-    """
+    """ 
     try:
         res = SESSION.get(url, params=payload)
         res.raise_for_status()
     except requests.exceptions.HTTPError as message:
-        print(message)
+        print(message, file=get_output())
         return(None)
 
     return(res)
@@ -274,7 +283,7 @@ def request_get(url, dataType='regular', payload=None, jsonify_data=True):
             res.raise_for_status()
             data = res.json()
         except (requests.exceptions.HTTPError, AttributeError) as message:
-            print(message)
+            print(message, file=get_output())
             return(data)
     else:
         res = SESSION.get(url, params=payload)
@@ -284,7 +293,7 @@ def request_get(url, dataType='regular', payload=None, jsonify_data=True):
         try:
             data = data['results']
         except KeyError as message:
-            print("{0} is not a key in the dictionary".format(message))
+            print("{0} is not a key in the dictionary".format(message), file=get_output())
             return([None])
     elif (dataType == 'pagination'):
         counter = 2
@@ -292,20 +301,20 @@ def request_get(url, dataType='regular', payload=None, jsonify_data=True):
         try:
             data = data['results']
         except KeyError as message:
-            print("{0} is not a key in the dictionary".format(message))
+            print("{0} is not a key in the dictionary".format(message), file=get_output())
             return([None])
 
         if nextData['next']:
-            print('Found Additional pages.')
+            print('Found Additional pages.', file=get_output())
         while nextData['next']:
             try:
                 res = SESSION.get(nextData['next'])
                 res.raise_for_status()
                 nextData = res.json()
             except:
-                print('Additional pages exist but could not be loaded.')
+                print('Additional pages exist but could not be loaded.', file=get_output())
                 return(data)
-            print('Loading page '+str(counter)+' ...')
+            print('Loading page '+str(counter)+' ...', file=get_output())
             counter += 1
             for item in nextData['results']:
                 data.append(item)
@@ -313,7 +322,7 @@ def request_get(url, dataType='regular', payload=None, jsonify_data=True):
         try:
             data = data['results'][0]
         except KeyError as message:
-            print("{0} is not a key in the dictionary".format(message))
+            print("{0} is not a key in the dictionary".format(message), file=get_output())
             return(None)
         except IndexError as message:
             return(None)
@@ -349,7 +358,7 @@ def request_post(url, payload=None, timeout=16, json=False, jsonify_data=True):
             res = SESSION.post(url, data=payload, timeout=timeout)
         data = res.json()
     except Exception as message:
-        print("Error in request_post: {0}".format(message))
+        print("Error in request_post: {0}".format(message), file=get_output())
     # Either return response <200,401,etc.> or the data that is returned from requests.
     if jsonify_data:
         return(data)
@@ -371,7 +380,7 @@ def request_delete(url):
         data = res
     except Exception as message:
         data = None
-        print("Error in request_delete: {0}".format(message))
+        print("Error in request_delete: {0}".format(message), file=get_output())
         
     return(data)
 
