@@ -1,7 +1,7 @@
 """Contains functions for getting information about options."""
+import sys
 import robin_stocks.helper as helper
 import robin_stocks.urls as urls
-import sys
 
 def spinning_cursor():
     """ This is a generator function to yield a character. """
@@ -13,11 +13,12 @@ spinner = spinning_cursor()
 
 def write_spinner():
     """ Function to create a spinning cursor to tell user that the code is working on getting market data. """
-    marketString = 'Loading Market Data '
-    sys.stdout.write(marketString)
-    sys.stdout.write(next(spinner))
-    sys.stdout.flush()
-    sys.stdout.write('\b'*(len(marketString)+1))
+    if helper.get_output()==sys.stdout:
+        marketString = 'Loading Market Data '
+        sys.stdout.write(marketString)
+        sys.stdout.write(next(spinner))
+        sys.stdout.flush()
+        sys.stdout.write('\b'*(len(marketString)+1))
 
 @helper.login_required
 def get_aggregate_positions(info=None):
@@ -96,7 +97,7 @@ def get_chains(symbol, info=None):
     try:
         symbol = symbol.upper().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return None
 
     url = urls.chains(symbol)
@@ -104,7 +105,7 @@ def get_chains(symbol, info=None):
 
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def find_tradable_options(symbol, expirationDate=None, strikePrice=None, optionType=None, info=None):
     """Returns a list of all available options for a stock.
 
@@ -125,12 +126,12 @@ def find_tradable_options(symbol, expirationDate=None, strikePrice=None, optionT
     try:
         symbol = symbol.upper().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     url = urls.option_instruments()
     if not helper.id_for_chain(symbol):
-        print("Symbol {} is not valid for finding options.".format(symbol))
+        print("Symbol {} is not valid for finding options.".format(symbol), file=helper.get_output())
         return [None]
 
     payload = {'chain_id': helper.id_for_chain(symbol),
@@ -138,7 +139,7 @@ def find_tradable_options(symbol, expirationDate=None, strikePrice=None, optionT
                'state': 'active'}
 
     if expirationDate:
-        payload['expiration_date'] = expirationDate
+        payload['expiration_dates'] = expirationDate
     if strikePrice:
         payload['strike_price'] = strikePrice
     if optionType:
@@ -147,7 +148,7 @@ def find_tradable_options(symbol, expirationDate=None, strikePrice=None, optionT
     data = helper.request_get(url, 'pagination', payload)
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def find_options_by_expiration(inputSymbols, expirationDate, optionType=None, info=None):
     """Returns a list of all the option orders that match the seach parameters
 
@@ -168,7 +169,7 @@ def find_options_by_expiration(inputSymbols, expirationDate, optionType=None, in
         if optionType:
             optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     data = []
@@ -178,14 +179,14 @@ def find_options_by_expiration(inputSymbols, expirationDate, optionType=None, in
 
         for item in filteredOptions:
             marketData = get_option_market_data_by_id(item['id'])
-            item.update(marketData)
+            item.update(marketData[0])
             write_spinner()
 
         data.extend(filteredOptions)
 
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def find_options_by_strike(inputSymbols, strikePrice, optionType=None, info=None):
     """Returns a list of all the option orders that match the seach parameters
 
@@ -206,7 +207,7 @@ def find_options_by_strike(inputSymbols, strikePrice, optionType=None, info=None
         if optionType:
             optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     data = []
@@ -215,14 +216,14 @@ def find_options_by_strike(inputSymbols, strikePrice, optionType=None, info=None
 
         for item in filteredOptions:
             marketData = get_option_market_data_by_id(item['id'])
-            item.update(marketData)
+            item.update(marketData[0])
             write_spinner()
 
         data.extend(filteredOptions)
 
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def find_options_by_expiration_and_strike(inputSymbols, expirationDate, strikePrice, optionType=None, info=None):
     """Returns a list of all the option orders that match the seach parameters
 
@@ -245,7 +246,7 @@ def find_options_by_expiration_and_strike(inputSymbols, expirationDate, strikePr
         if optionType:
             optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     data = []
@@ -255,14 +256,14 @@ def find_options_by_expiration_and_strike(inputSymbols, expirationDate, strikePr
 
         for item in filteredOptions:
             marketData = get_option_market_data_by_id(item['id'])
-            item.update(marketData)
+            item.update(marketData[0])
             write_spinner()
 
         data.extend(filteredOptions)
 
     return helper.filter(data, info)
 
-
+@helper.login_required
 def find_options_by_specific_profitability(inputSymbols, expirationDate=None, strikePrice=None, optionType=None, typeProfit="chance_of_profit_short", profitFloor=0.0, profitCeiling=1.0, info=None):
     """Returns a list of option market data for several stock tickers that match a range of profitability.
 
@@ -290,7 +291,7 @@ def find_options_by_specific_profitability(inputSymbols, expirationDate=None, st
     data = []
 
     if (typeProfit != "chance_of_profit_short" and typeProfit != "chance_of_profit_long"):
-        print("Invalid string for 'typeProfit'. Defaulting to 'chance_of_profit_short'.")
+        print("Invalid string for 'typeProfit'. Defaulting to 'chance_of_profit_short'.", file=helper.get_output())
         typeProfit = "chance_of_profit_short"
 
     for symbol in symbols:
@@ -300,19 +301,21 @@ def find_options_by_specific_profitability(inputSymbols, expirationDate=None, st
                 continue
 
             market_data = get_option_market_data_by_id(option['id'])
-            option.update(market_data)
-            write_spinner()
+            
+            if len(market_data):
+                option.update(market_data[0])
+                write_spinner()
 
-            try:
-                floatValue = float(option[typeProfit])
-                if (floatValue >= profitFloor and floatValue <= profitCeiling):
-                    data.append(option)
-            except:
-                pass
+                try:
+                    floatValue = float(option[typeProfit])
+                    if (floatValue >= profitFloor and floatValue <= profitCeiling):
+                        data.append(option)
+                except:
+                    pass
 
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def get_option_market_data_by_id(id, info=None):
     """Returns the option market data for a stock, including the greeks,
     open interest, change of profit, and adjusted mark price.
@@ -325,8 +328,12 @@ def get_option_market_data_by_id(id, info=None):
     If info parameter is provided, the value of the key that matches info is extracted.
 
     """
-    url = urls.marketdata_options(id)
-    data = helper.request_get(url)
+    instrument = get_option_instrument_data_by_id(id)
+    url = urls.marketdata_options()
+    payload = {
+        "instruments" : instrument['url']
+    }
+    data = helper.request_get(url, 'results', payload)
 
     if not data:
         data= {
@@ -362,7 +369,7 @@ def get_option_market_data_by_id(id, info=None):
 
     return(helper.filter(data, info))
 
-
+@helper.login_required
 def get_option_market_data(inputSymbols, expirationDate, strikePrice, optionType, info=None):
     """Returns the option market data for the stock option, including the greeks,
     open interest, change of profit, and adjusted mark price.
@@ -386,7 +393,7 @@ def get_option_market_data(inputSymbols, expirationDate, strikePrice, optionType
         if optionType:
             optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     data = []
@@ -435,7 +442,7 @@ def get_option_instrument_data(symbol, expirationDate, strikePrice, optionType,
         symbol = symbol.upper().strip()
         optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     optionID = helper.id_for_option(symbol, expirationDate, strikePrice, optionType)
@@ -473,7 +480,7 @@ def get_option_historicals(symbol, expirationDate, strikePrice, optionType, inte
         symbol = symbol.upper().strip()
         optionType = optionType.lower().strip()
     except AttributeError as message:
-        print(message)
+        print(message, file=helper.get_output())
         return [None]
 
     interval_check = ['5minute', '10minute', 'hour', 'day', 'week']
@@ -481,13 +488,13 @@ def get_option_historicals(symbol, expirationDate, strikePrice, optionType, inte
     bounds_check = ['extended', 'regular', 'trading']
     if interval not in interval_check:
         print(
-            'ERROR: Interval must be "5minute","10minute","hour","day",or "week"')
+            'ERROR: Interval must be "5minute","10minute","hour","day",or "week"', file=helper.get_output())
         return([None])
     if span not in span_check:
-        print('ERROR: Span must be "day", "week", "year", or "5year"')
+        print('ERROR: Span must be "day", "week", "year", or "5year"', file=helper.get_output())
         return([None])
     if bounds not in bounds_check:
-        print('ERROR: Bounds must be "extended","regular",or "trading"')
+        print('ERROR: Bounds must be "extended","regular",or "trading"', file=helper.get_output())
         return([None])
 
     optionID = helper.id_for_option(symbol, expirationDate, strikePrice, optionType)
